@@ -60,35 +60,35 @@ def create_derivatives_for_instrument_dic(instrument_data, initial_asset_price):
     type = None
     long_immediate_cost = np.nan
     short_immediate_gain = np.nan
-    # if name.endswith("C"):
-    #     type = 'CALL'
-    #     # long
-    #     long_immediate_cost = - best_ask
-    #     short_immediate_gain = best_bid
-    #     long_payoff_fun = lambda x: max(0, x - strike)
-    #     # short
-    #     short_payoff_fun = lambda x:  -max(0, x - strike)
-    # else:  # put
-    #     type = 'PUT'
-    #     long_immediate_cost = - best_ask
-    #     short_immediate_gain = best_bid
-    #
-    #     # long
-    #     long_payoff_fun = lambda x: max(0, strike - x)
-    #     # short
-    #     short_payoff_fun = lambda x:  -max(0, strike - x)
     if name.endswith("C"):
         type = 'CALL'
         # long
-        long_payoff_fun = lambda x: max(0, x - strike) - best_ask
+        long_immediate_cost = - best_ask
+        short_immediate_gain = best_bid
+        long_payoff_fun = lambda x: max(0, x - strike)
         # short
-        short_payoff_fun = lambda x: best_bid - max(0, x - strike)
+        short_payoff_fun = lambda x:  -max(0, x - strike)
     else:  # put
         type = 'PUT'
+        long_immediate_cost = - best_ask
+        short_immediate_gain = best_bid
+
         # long
-        long_payoff_fun = lambda x: max(0, strike - x) - best_ask
+        long_payoff_fun = lambda x: max(0, strike - x)
         # short
-        short_payoff_fun = lambda x: best_bid - max(0, strike - x)
+        short_payoff_fun = lambda x:  -max(0, strike - x)
+    # if name.endswith("C"):
+    #     type = 'CALL'
+    #     # long
+    #     long_payoff_fun = lambda x: max(0, x - strike) - best_ask
+    #     # short
+    #     short_payoff_fun = lambda x: best_bid - max(0, x - strike)
+    # else:  # put
+    #     type = 'PUT'
+    #     # long
+    #     long_payoff_fun = lambda x: max(0, strike - x) - best_ask
+    #     # short
+    #     short_payoff_fun = lambda x: best_bid - max(0, strike - x)
 
     deriv_dic ={
         'name': name + "_LONG",
