@@ -1493,7 +1493,7 @@ def compute_alpha_signal_dynamical_ls_neutral(lo_df=None, core_tokens=['BTC', 'E
     return merged_df.copy()
 
 
-def combine_lo_sigs(lo_df = None, rsilo_df = None, core_tokens=None, extra_tokens=None):
+def combine_lo_sigs(lo_df = None, rsilo_df = None, core_tokens=None, extra_tokens=None,plot_all_strat = True):
     daily_rsi_lo_df = riskmetrics.filter_daily(rsilo_df.copy())
     lo_close_colums = [f'close_{tok}' for tok in core_tokens + extra_tokens]
     rsilo_close_colums = [f'close_{tok}' for tok in core_tokens]
@@ -1569,8 +1569,7 @@ def combine_lo_sigs(lo_df = None, rsilo_df = None, core_tokens=None, extra_token
 
     new_merged_sig_df['strat'] = np.cumprod(1. + new_merged_sig_df['strat_return'].values)
 
-    plot_html = True
-    if plot_html:
+    if plot_all_strat:
         dollar_df = new_merged_sig_df[['strat']].copy()
         new_names = {'strat': 'Absolute Return Weekly LO Strategy'}
         dollar_df = dollar_df.rename(columns=new_names)
@@ -1579,4 +1578,9 @@ def combine_lo_sigs(lo_df = None, rsilo_df = None, core_tokens=None, extra_token
                                                                          put_on_same_scale=False,
                                                                          title=f'strategy performance')
         fig.show()
+        fig = realtime_plotting_utility.plot_dollar_multiple_time_series(data_df=dollar_df,
+                                                                         logy=False, split=False,
+                                                                         put_on_same_scale=False,
+                                                                         title=f'strategy performance')
+        fig.show()
     return new_merged_sig_df
\ No newline at end of file
